From 00b23e51aecab7902f0fe0a0b138698ad28caea2 Mon Sep 17 00:00:00 2001
From: Justin Clark-Casey (justincc)
Date: Sat, 11 Oct 2014 00:14:35 +0100
Subject: Change name of just added OSSL osForceSit() to osForceOtherSit()

This is somewhat more in keeping with something like osForceAttachToOtherAvatarFromInventory()
and potentially allows a separate osForceSit() command with High threat rather than VeryHigh that only sits the owner and can be enabled without enabling sit of other avatars.
---
 .../Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs  | 10 +++++-----
 OpenSim/Region/ScriptEngine/Shared/Api/Interface/IOSSL_Api.cs  |  4 ++--
 OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs    |  9 +++++----
 3 files changed, 12 insertions(+), 11 deletions(-)

(limited to 'OpenSim')

diff --git a/OpenSim/Region/ScriptEngine/Shared/Api/Interface/IOSSL_Api.cs b/OpenSim/Region/ScriptEngine/Shared/Api/Interface/IOSSL_Api.cs
index 83a0808..38d4574 100644
--- a/OpenSim/Region/ScriptEngine/Shared/Api/Interface/IOSSL_Api.cs
+++ b/OpenSim/Region/ScriptEngine/Shared/Api/Interface/IOSSL_Api.cs
@@ -363,8 +363,8 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api.Interfaces
         LSL_Float osGetHealth(string avatar);
         void osCauseHealing(string avatar, double healing);
         void osCauseDamage(string avatar, double damage);
-        void osForceSit(string avatar);
-        void osForceSit(string avatar, string target);
+        void osForceOtherSit(string avatar);
+        void osForceOtherSit(string avatar, string target);
         LSL_List osGetPrimitiveParams(LSL_Key prim, LSL_List rules);
         void osSetPrimitiveParams(LSL_Key prim, LSL_List rules);
         void osSetProjectionParams(bool projection, LSL_Key texture, double fov, double focus, double amb);
diff --git a/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs b/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
index da88cc4..352a35d 100644
--- a/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
+++ b/OpenSim/Region/ScriptEngine/Shared/Api/Runtime/OSSL_Stub.cs
@@ -920,13 +920,14 @@ namespace OpenSim.Region.ScriptEngine.Shared.ScriptBase
             m_OSSL_Functions.osCauseHealing(avatar, healing);
         }
 
-        public void osForceSit(string avatar)
+        public void osForceOtherSit(string avatar)
         {
-            m_OSSL_Functions.osForceSit(avatar);
+            m_OSSL_Functions.osForceOtherSit(avatar);
         }
-        public void osForceSit(string avatar, string target)
+
+        public void osForceOtherSit(string avatar, string target)
         {
-            m_OSSL_Functions.osForceSit(avatar, target);
+            m_OSSL_Functions.osForceOtherSit(avatar, target);
         }
         
         public LSL_List osGetPrimitiveParams(LSL_Key prim, LSL_List rules)
diff --git a/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs b/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
index 60ab75e..704ff15 100644
--- a/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
+++ b/OpenSim/Region/ScriptEngine/Shared/Api/Implementation/OSSL_Api.cs
@@ -880,9 +880,9 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
         /// Does work if passed key (or keys if overloaded).
         /// </summary>
         /// <param name="avatar"></param>
-        public void osForceSit(string avatar)
+        public void osForceOtherSit(string avatar)
         {
-            CheckThreatLevel(ThreatLevel.VeryHigh, "osForceSit");
+            CheckThreatLevel(ThreatLevel.VeryHigh, "osForceOtherSit");
 
             m_host.AddScriptLPS(1);
 
@@ -890,14 +890,14 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
         }
 
         /// <summary>
         /// Overload method of osForceSit(string avatar) to allow a script NOT in the target prim to force
         /// an avatar to sit on the target prim using normal methods as if called by the client.
         /// </summary>
         /// <param name="avatar"></param>
         /// <param name="target"></param>
-        public void osForceSit(string avatar, string target)
+        public void osForceOtherSit(string avatar, string target)
         {
-            CheckThreatLevel(ThreatLevel.VeryHigh, "osForceSit");
+            CheckThreatLevel(ThreatLevel.VeryHigh, "osForceOtherSit");
 
             m_host.AddScriptLPS(1);
 
@@ -890,14 +890,14 @@ namespace OpenSim.Region.ScriptEngine.Shared.Api
 
         /// <summary>
-        /// Overload method of osForceSit(string avatar) to allow a script NOT in the target prim to force
+        /// Overload method of osForceOtherSit(string avatar) to allow a script NOT in the target prim to force
         /// an avatar to sit on the target prim using normal methods as if called by the client.
         /// </summary>
-- 
cgit v1.1